# -*- coding: utf-8 -*-
"""Command line arg for sixties."""
import sys
from typing import List, Union


def main(argv: Union[List[str], None] = None) -> int:
    """Drive the understanding ..."""
    argv = sys.argv if argv is None else argv
    print(argv)
    return 0



# -*- coding: utf-8 -*-

# [[[fill git_describe()]]]
__version__ = '2023.10.22+parent.f7a532b5'
# [[[end]]] (checksum: 77104eef85a5ba8fcb38d4d6eea72a1f)
__version_info__ = tuple(
    e if '-' not in e else e.split('-')[0] for part in __version__.split('+') for e in part.split('.') if e != 'parent'
)



# -*- coding: utf-8 -*-
from sixties import cli


def test_cli_main_ok(capsys):
    argv = ['ignored', 'printed']
    assert cli.main(argv) == 0
    out, err = capsys.readouterr()
    assert out.strip() == str(argv)
    assert not err
